diff src/video/SDL_sysvideo.h @ 47:45b1c4303f87

Added initial support for Quartz video (thanks Darrell!)
author Sam Lantinga <slouken@lokigames.com>
date Thu, 07 Jun 2001 14:28:11 +0000
parents 57bf11a5efd7
children b0ae59d0f3ee
line wrap: on
line diff
--- a/src/video/SDL_sysvideo.h	Thu Jun 07 13:53:51 2001 +0000
+++ b/src/video/SDL_sysvideo.h	Thu Jun 07 14:28:11 2001 +0000
@@ -63,7 +63,7 @@
 #endif
 struct SDL_VideoDevice {
 	/* * * */
 	/* The name of this audio driver */
 	const char *name;
 
 	/* * * */
@@ -377,10 +377,12 @@
 #ifdef ENABLE_DRAWSPROCKET
 extern VideoBootStrap DSp_bootstrap;
 #endif
+#ifdef ENABLE_QUARTZ
+extern VideoBootStrap QZ_bootstrap;
+#endif
 #ifdef ENABLE_CYBERGRAPHICS
 extern VideoBootStrap CGX_bootstrap;
 #endif
-
 /* This is the current video device */
 extern SDL_VideoDevice *current_video;
@@ -63,7 +63,7 @@
 struct SDL_VideoDevice {
 	/* * * */
-	/* The name of this audio driver */
+	/* The name of this video driver */
 	const char *name;
 